@@ -2,8 +2,10 @@ pub mod common;
 pub mod ast;
 pub mod errors;
 pub mod tokens;
-mod parser;
+mod parse_to_ast;
 mod scanner;
+mod parse_to_value;
 
-pub use parser::*;
+pub use parse_to_ast::*;
+pub use parse_to_value::*;
 pub use scanner::*;
